Class for visitation_model predictions (for use with predict.visitation_model()).
new_visitation_forecast(
forecasts,
logged_forecasts,
differenced_logged_forecasts,
differenced_standard_forecasts,
n_ahead,
proxy_forecasts,
onsite_usage_forecasts,
beta,
constant,
slope,
criterion,
past_observations,
lag_estimate
)Object of class "labeled_visitation_forecast".
Object of class "Visitation_forecast".
A time series of forecasts for the visitation model. the forecasts will be in the standard scale of visitors per month
A time series of the logged forecasts for the visitation model.
A time series of the differenced logged forecasts for the visitation model.
A time series of the exponentiated differenced logged forecasts that are for the visitation model.
An integer describing the number of forecasts made.
A time series of forecasts of the popularity proxy series.
A time series of forecasts of the original time series.
A numeric or a character string specifying the seasonality adjustment factor. (beta_1)
A numeric specifying the constant term in the model. This constant is understood as the mean of the trend-adjusted time_series. (beta_0)
A numeric specifying the slope term in the model when a linear trend is assumed. (beta_2)
One of "MSE" or "Nonparametric", to specify the criterion used to select the lag.
One of "none", "fitted", or "ref_series". If "fitted", past model fitted values are used. If "ref_series", the reference series in the visitation model object is used. Note that if difference = TRUE, one of these is needed to forecast the first difference.
A numeric value specifying the estimated lag in the visitation model.